Skip to main content

Starknet interface generator

Generate / check the interfaces corresponding to your Starknet contracts.

Installation

pip install starknet-interface-generator

Usage

Options :

Generate interfaces

Usage: starknet-interface-generator generate [OPTIONS]

Options:
  --files TEXT          File paths
  -p, --protostar       Uses `protostar.toml` to get file paths
  -d, --directory TEXT  Output directory for the interfaces. If unspecified,
                        they will be created in the same directory as the
                        contracts
  --help                Show this message and exit.

Check existing interfaces

starknet-interface-generator check [OPTIONS]

Options:
  --files TEXT          Contracts to check
  -p, --protostar       Uses `protostar.toml` to get file paths
  -d, --directory TEXT  Directory of the interfaces to check. Interfaces must
                        be named `i_<contract_name>.cairo`
  --help                Show this message and exit.

Example

Generate interfaces for the contracts in contracts/ and put them in interfaces/:

find contracts/ -iname '*.cairo' -exec starknet-interface-generator generate --files {} \;

Check the interface for test/main.cairo against the interface i_main.cairo in interfaces/:

starknet-interface-generator check --files test/main.cairo -d interfaces

Protostar

You can use starknet-interface-generator in a protostar project. This can be paired with a github action to automatically generate the interfaces for the contracts that specified inside the protostar.toml file.

starknet-interface-generator [generate||check] --protostar

Metadata

Release files for starknet-interface-generator 0.1.5

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for starknet-interface-generator 0.1.5
File Size Uploaded Provenance Actions
starknet-interface-generator-0.1.5.tar.gz 6.2 kB Without provenance Details for starknet-interface-generator-0.1.5.tar.gz

Built distribution (wheel)

Table of built distributions (wheels) for starknet-interface-generator 0.1.5
File Interpreter ABI Platform Actions
starknet_interface_generator-0.1.5-py3-none-any.whl Python 3 none any Details for starknet_interface_generator-0.1.5-py3-none-any.whl

Total release size: 14.5 kB

Release files / starknet-interface-generator-0.1.5.tar.gz

Download URL starknet-interface-generator-0.1.5.tar.gz
Size 6.2 kB
Tags Source
SHA-256 checksum
How to use checksums
69a3a373298a2fa7a1e2376e159c21d11e428d32c8f511fa9ab310cac8668db8
BLAKE2b-256 checksum
How to use checksums
a70f5f74ec59a3d8db3c56cd7f33f1f6a4d112f6f259abfaf3ae539d06c6813e
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/4.0.1 CPython/3.10.7

Release files / starknet_interface_generator-0.1.5-py3-none-any.whl

Download URL starknet_interface_generator-0.1.5-py3-none-any.whl
Size 8.2 kB
Tags Python 3
SHA-256 checksum
How to use checksums
6a67a91ddfbca4a035dd1ad8839dac8a9469063a54bb6fc278344dc28b40178f
BLAKE2b-256 checksum
How to use checksums
b1805460c31fc73d90bd621021610a2f614478f1a3dc1d1fe5929bfc7c3d11d8
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/4.0.1 CPython/3.10.7

Security for starknet-interface-generator 0.1.5

Provenance

Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.

No provenance found

None of the files in this release were uploaded with provenance metadata.

A note on package security

PyPI is a repository for distributing packages, not a service for auditing them. While third-party security researchers and our staff do their best to detect and remove malicious packages, PyPI cannot guarantee the quality, security or suitability of any given package.

To learn more about protecting yourself from malicious actors, visit our package security documentation.

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page